pyxu-gradient-descent
=====================

.. image:: https://img.shields.io/pypi/l/pyxu-gradient-descent.svg?color=green
   :target: https://github.com/joanrue/pyxu-gradient-descent/raw/main/LICENSE
   :alt: License MIT
.. image:: https://img.shields.io/pypi/v/pyxu-gradient-descent.svg?color=green
   :target: https://pypi.org/project/pyxu-gradient-descent
   :alt: PyPI
.. image:: https://github.com/joanrue/pyxu-gradient-descent/workflows/tests/badge.svg
   :target: https://github.com/joanrue/pyxu-gradient-descent/actions
   :alt: tests
.. image:: https://codecov.io/gh/joanrue/pyxu-gradient-descent/branch/main/graph/badge.svg
   :target: https://codecov.io/gh/joanrue/pyxu-gradient-descent
   :alt: codecov
.. image:: https://img.shields.io/endpoint?url=https://pyxu-org.github.io/fair/shields/pyxu-gradient-descent
   :alt: Pyxu score
   :target: https://pyxu-org.github.io/fair/score.html

An accelerated gradient descent optimizer for Pyxu
--------------------------------------------------

This `Pyxu`_ plugin was generated with `Cookiecutter`_ using the `cookiecutter-pyxu`_ template.

.. Don't miss the `contributing-guide`_ to set up your new package and to review the Pyxu `developer notes`_.

Installation
------------

You can install ``pyxu-gradient-descent`` via `pip`_:

.. code-block:: bash

   pip install pyxu-gradient-descent


To install latest development version :

.. code-block:: bash

   pip install git+https://github.com/joanrue/pyxu-gradient-descent.git


Contributing
------------

Contributions are very welcome. Tests can be run with `tox`_, please ensure
the coverage at least stays the same before you submit a pull request.

License
-------

Distributed under the terms of the `MIT`_ license,
``pyxu-gradient-descent`` is free and open source software

Issues
------

If you encounter any problems, please `file an issue`_ along with a detailed description.

.. _Pyxu: https://github.com/pyxu-org/pyxu
.. _contributing-guide: https://pyxu-org.github.io/fair/contribute.html
.. _developer notes: https://pyxu-org.github.io/fair/dev_notes.html
.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _MIT: http://opensource.org/licenses/MIT
.. _BSD-3: http://opensource.org/licenses/BSD-3-Clause
.. _GNU GPL v3.0: http://www.gnu.org/licenses/gpl-3.0.txt
.. _GNU LGPL v3.0: http://www.gnu.org/licenses/lgpl-3.0.txt
.. _Apache Software License 2.0: http://www.apache.org/licenses/LICENSE-2.0
.. _Mozilla Public License 2.0: https://www.mozilla.org/media/MPL/2.0/index.txt
.. _cookiecutter-pyxu: https://github.com/pyxu-org/cookiecutter-pyxu

.. _file an issue: https://github.com/joanrue/pyxu-gradient-descent/issues

.. _tox: https://tox.readthedocs.io/en/latest/
.. _pip: https://pypi.org/project/pip/
